@@ -123,12 +123,22 @@ class Emulator:
     :type modules Modules
     :type memory Memory
     """
-    def __init__(self, vfs_root="vfs", config_path="sower_androidemu/emu_cfg/default.json", vfp_inst_set=True, arch=emu_const.ARCH_ARM32, muti_task=False):
+    def __init__(self, vfs_root="vfs", config_path="emu_cfg/default.json", vfp_inst_set=True, arch=emu_const.ARCH_ARM32, muti_task=False):
         # Unicorn.
         sys.stdout = sys.stderr
         #由于这里的stream只能改一次，为避免与fork之后的子进程写到stdout混合，将这些log写到stderr
         #FIXME:解除这种特殊的依赖
-        self.config = config.Config(config_path)
+        self.config ={
+	"__pkg_name":"com.netease.cloudmusic",
+	"pkg_name":"com.ss.android.ugc.aweme",
+	"pid": 4386,
+	"uid": 10023,
+	"android_id": "39cc04a2ae83db0b",
+	"ip":"192.168.31.52",
+	"mac":[204, 250, 166, 0, 138, 169]
+}
+
+        #self.config = config.Config(config_path)
         self.__arch = arch
         self.__support_muti_task = muti_task
         self.__pcb = pcb.Pcb()
